@@ -16,7 +16,6 @@
 
 """Juniper JCL generator."""
 
-
 from typing import Dict, List, Set, Tuple, Union
 
 from absl import logging
@@ -233,11 +232,12 @@ class Term(aclgenerator.Term):
             self.term_type == 'inet'
             and ('icmpv6' in self.term.protocol or 'icmp6' in self.term.protocol)
         ):
-            logging.warning(
-                self.NO_AF_LOG_PROTO.substitute(
-                    term=self.term.name, proto=', '.join(self.term.protocol), af=self.term_type
+            if self.filter_type != 'mixed':
+                logging.warning(
+                    self.NO_AF_LOG_PROTO.substitute(
+                        term=self.term.name, proto=', '.join(self.term.protocol), af=self.term_type
+                    )
                 )
-            )
             return ''
 
         # comment
@@ -486,17 +486,25 @@ class Term(aclgenerator.Term):
 
             # protocol
             if self.term.protocol:
+                # Juniper has deprecated the use of icmpv6 in favor of icmp6.
+                # https://github.com/aerleon/aerleon/issues/323
+                protocol = self.term.protocol[:]
+                if 'icmpv6' in self.term.protocol:
+                    loc = protocol.index('icmpv6')
+                    protocol[loc] = 'icmp6'
                 # both are supported on JunOS, but only icmp6 is supported
                 # on SRX loopback stateless filter
-                config.Append(family_keywords['protocol'] + ' ' + self._Group(self.term.protocol))
+                config.Append(family_keywords['protocol'] + ' ' + self._Group(protocol))
 
             # protocol
             if self.term.protocol_except:
                 # same as above
+                protocol_except = self.term.protocol_except[:]
+                if 'icmpv6' in self.term.protocol_except:
+                    loc = protocol_except.index('icmpv6')
+                    protocol_except[loc] = 'icmp6'
                 config.Append(
-                    family_keywords['protocol-except']
-                    + ' '
-                    + self._Group(self.term.protocol_except)
+                    family_keywords['protocol-except'] + ' ' + self._Group(protocol_except)
                 )
 
             # port
