@@ -134,11 +134,14 @@ class Term(aclgenerator.Term):
         if (self.af == 6 and 'icmp' in self.term.protocol) or (
             self.af == 4 and 'icmpv6' in self.term.protocol
         ):
-            logging.warning(
-                self.NO_AF_LOG_PROTO.substitute(
-                    term=self.term.name, proto=self.term.protocol, af=self.filter_type
+            if self.filter_type != 'mixed':
+                logging.warning(
+                    self.NO_AF_LOG_PROTO.substitute(
+                        term=self.term.name,
+                        proto=', '.join(self.term.protocol),
+                        af=self.filter_type,
+                    )
                 )
-            )
             return ''
 
         # Term verbatim is not supported
