@@ -28,8 +28,7 @@ from typing import Any, DefaultDict, Dict, List, Set, Tuple, Union
 
 from absl import logging
 
-from aerleon.lib import aclgenerator
-from aerleon.lib.policy import Policy, Term
+from aerleon.lib import aclgenerator, policy
 
 if sys.version_info < (3, 8):
     from typing_extensions import TypedDict
@@ -49,13 +48,23 @@ class ExceededAttributeCountError(Error):
     """Raised when the total attribute count of a policy is above the maximum."""
 
 
+class TcpEstablishedWithNonTcpError(Error):
+    """Raised when the TCP established option is set with a non TCP protocol."""
+
+
 # Graceful handling of dict heierarchy for OpenConfig JSON.
 def RecursiveDict() -> DefaultDict[Any, Any]:
     return defaultdict(RecursiveDict)
 
 
 TransportConfig = TypedDict(
-    "TransportConfig", {"source-port": Union[int, str], "destination-port": Union[int, str]}
+    "TransportConfig",
+    {
+        "source-port": Union[int, str],
+        "destination-port": Union[int, str],
+        "detail-mode": str,
+        "builtin-detail": str,
+    },
 )
 Transport = TypedDict("Transport", {"transport": TransportConfig})
 IPConfig = TypedDict(
@@ -70,6 +79,7 @@ ACLEntry = TypedDict(
 )
 aclEntries = TypedDict("aclEntries", {"acl-entry": List[ACLEntry]})
 ACLSetConfig = TypedDict("ACLSetConfig", {"name": str, "type": str})
+
 ACLSet = TypedDict(
     "ACLSet", {"acl-entries": aclEntries, "config": ACLSetConfig, "name": str, "type": str}
 )
@@ -89,7 +99,7 @@ class Term(aclgenerator.Term):
         6: 'ipv6',
     }
 
-    def __init__(self, term: Term, inet_version: str = 'inet') -> None:
+    def __init__(self, term: policy.Term, inet_version: str = 'inet') -> None:
         super().__init__(term)
         self.term = term
         self.inet_version = inet_version
@@ -103,6 +113,13 @@ class Term(aclgenerator.Term):
         rules = self.ConvertToDict()
         json.dumps(rules, indent=2)
 
+    def _tcp_established(self) -> Dict[str, str]:
+        """Return's openconfig TCP_ESTABLISHED configuration.
+
+        Other vendors (eg. SONiC) have slighly different implementations,
+        This function permits inheritance."""
+        return {'detail-mode': 'BUILTIN', 'builtin-detail': "TCP_ESTABLISHED"}
+
     def ConvertToDict(
         self,
     ) -> List[ACLEntry]:
@@ -116,7 +133,7 @@ class Term(aclgenerator.Term):
           A list of dictionaries that contains all fields necessary to create or
           update a OpenConfig acl-entry.
         """
-        term_dict = RecursiveDict()
+        self.term_dict = RecursiveDict()
 
         # Rules will hold all exploded acl-entry dictionaries.
         rules = []
@@ -126,10 +143,7 @@ class Term(aclgenerator.Term):
         family = self.AF_RENAME[term_af]
 
         # Action
-        action = self.ACTION_MAP[self.term.action[0]]
-        term_dict['actions'] = {}
-        term_dict['actions']['config'] = {}
-        term_dict['actions']['config']['forwarding-action'] = action
+        self.SetAction()
 
         # Ballot fatigue handling for 'any'.
         saddrs = self.term.GetAddressOfVersion('flattened_saddr', term_af)
@@ -152,39 +166,34 @@ class Term(aclgenerator.Term):
         if not protos:
             protos = ['none']
 
-        ace_dict = copy.deepcopy(term_dict)
+        self.term_dict = copy.deepcopy(self.term_dict)
+
+        if self.term.comment:
+            self.SetComments(self.term.comment)
+
+        # Options
+        self.SetOptions(family)
+
         # Source Addresses
         for saddr in saddrs:
             if saddr != 'any':
-                ace_dict[family]['config']['source-address'] = str(saddr)
+                self.SetSourceAddress(family, str(saddr))
 
             # Destination Addresses
             for daddr in daddrs:
                 if daddr != 'any':
-                    ace_dict[family]['config']['destination-address'] = str(daddr)
+                    self.SetDestAddress(family, str(daddr))
 
                 # Source Port
                 for start, end in sports:
                     # 'any' starts and ends with zero.
                     if not start == end == 0:
-                        if start == end:
-                            ace_dict['transport']['config']['source-port'] = int(start)
-                        else:
-                            ace_dict['transport']['config']['source-port'] = '%d..%d' % (
-                                start,
-                                end,
-                            )
+                        self.SetSourcePorts(start, end)
 
                     # Destination Port
                     for start, end in dports:
                         if not start == end == 0:
-                            if start == end:
-                                ace_dict['transport']['config']['destination-port'] = int(start)
-                            else:
-                                ace_dict['transport']['config']['destination-port'] = '%d..%d' % (
-                                    start,
-                                    end,
-                                )
+                            self.SetDestPorts(start, end)
 
                         # Protocol
                         for proto in protos:
@@ -196,17 +205,62 @@ class Term(aclgenerator.Term):
                                         raise OcFirewallError(
                                             'Protocol %s unknown. Use an integer.', proto
                                         )
-                                    ace_dict[family]['config']['protocol'] = proto_num
-                                rules.append(copy.deepcopy(ace_dict))
+                                    self.SetProtocol(family, proto_num)
                             else:
-                                proto_num = proto
-                                ace_dict[family]['config']['protocol'] = proto_num
-                                # This is the business end of ace explosion.
-                                # A dict is a reference type, so deepcopy is atually required.
-                                rules.append(copy.deepcopy(ace_dict))
+                                self.SetProtocol(family, proto)
+
+                            # This is the business end of ace explosion.
+                            # A dict is a reference type, so deepcopy is actually required.
+                            rules.append(copy.deepcopy(self.term_dict))
 
         return rules
 
+    def SetAction(self) -> None:
+        action = self.ACTION_MAP[self.term.action[0]]
+        self.term_dict['actions'] = {}
+        self.term_dict['actions']['config'] = {}
+        self.term_dict['actions']['config']['forwarding-action'] = action
+
+    def SetComments(self, comments: List[str]) -> None:
+        pass
+
+    def SetOptions(self, family: str) -> None:
+        # options, 'family' unused
+        if self.term.option:
+            if 'tcp-established' in self.term.option:
+                if self.term.protocol != ['tcp']:
+                    raise TcpEstablishedWithNonTcpError(
+                        f'tcp-established can only be used with tcp protocol in term {self.term.name}'
+                    )
+                self.term_dict['transport']['config'].update(self._tcp_established())
+
+    def SetSourceAddress(self, family: str, saddr: str) -> None:
+        self.term_dict[family]['config']['source-address'] = saddr
+
+    def SetDestAddress(self, family: str, daddr: str) -> None:
+        self.term_dict[family]['config']['destination-address'] = daddr
+
+    def SetSourcePorts(self, start: int, end: int) -> None:
+        if start == end:
+            self.term_dict['transport']['config']['source-port'] = start
+        else:
+            self.term_dict['transport']['config']['source-port'] = '%d..%d' % (
+                start,
+                end,
+            )
+
+    def SetDestPorts(self, start: int, end: int) -> None:
+        if start == end:
+            self.term_dict['transport']['config']['destination-port'] = start
+        else:
+            self.term_dict['transport']['config']['destination-port'] = '%d..%d' % (
+                start,
+                end,
+            )
+
+    def SetProtocol(self, family: str, protocol: int) -> None:
+        self.term_dict[family]['config']['protocol'] = protocol
+
 
 class OpenConfig(aclgenerator.ACLGenerator):
     """A OpenConfig firewall policy object."""
@@ -215,6 +269,7 @@ class OpenConfig(aclgenerator.ACLGenerator):
     SUFFIX = '.oacl'
     _SUPPORTED_AF = frozenset(('inet', 'inet6', 'mixed'))
     FAMILY_MAP = {'mixed': 'ACL_MIXED', 'inet6': 'ACL_IPV6', 'inet': 'ACL_IPV4'}
+    _TERM = Term
 
     def _BuildTokens(self) -> Tuple[Set[str], Dict[str, Set[str]]]:
         """Build supported tokens for platform.
@@ -230,12 +285,24 @@ class OpenConfig(aclgenerator.ACLGenerator):
         # OpenConfig ACL model only supports these three forwarding actions.
         supported_sub_tokens['action'] = {'accept', 'deny', 'reject'}
 
+        supported_sub_tokens.update(
+            {
+                'option': {
+                    'tcp-established',
+                }
+            }
+        )
+
         return supported_tokens, supported_sub_tokens
 
-    def _TranslatePolicy(self, pol: Policy, exp_info: int) -> None:
-        total_rule_count = 0
+    def _InitACLSet(self) -> None:
+        """Initialize self.acl_sets with proper Typing"""
         self.acl_sets: List[ACLSet] = []
 
+    def _TranslatePolicy(self, pol: policy.Policy, exp_info: int) -> None:
+        self.total_rule_count = 0
+        self._InitACLSet()
+
         for header, terms in pol.filters:
             filter_options = header.FilterOptions(self._PLATFORM)
             filter_name = header.FilterName(self._PLATFORM)
@@ -249,41 +316,40 @@ class OpenConfig(aclgenerator.ACLGenerator):
                 if i in filter_options:
                     address_family = i
                     filter_options.remove(i)
+            self._TranslateTerms(terms, address_family, filter_name, header.comment)
 
-            oc_acl_entries: List[ACLEntry] = []
+        logging.info('Total rule count of policy %s is: %d', filter_name, self.total_rule_count)
 
-            for term in terms:
-                # TODO(b/196430344): Add support for options such as
-                # established/rst/first-fragment
-                if term.option:
-                    raise OcFirewallError('OpenConfig firewall does not support term options.')
+    def _TranslateTerms(
+        self, terms: List[Term], address_family: str, filter_name: str, hdr_comments: List[str]
+    ) -> None:
+        """
+        Factor out the translation of terms, such that it can be overridden by subclasses
+        """
+        oc_acl_entries: List[ACLEntry] = []
 
-                # Handle mixed for each indvidual term as inet and inet6.
-                # inet/inet6 are treated the same.
-                term_address_families = []
-                if address_family == 'mixed':
-                    term_address_families = ['inet', 'inet6']
-                else:
-                    term_address_families = [address_family]
-                for term_af in term_address_families:
-                    t = Term(term, term_af)
-
-                    for rule in t.ConvertToDict():
-                        total_rule_count += 1
-                        rule['sequence-id'] = total_rule_count * 5
-                        oc_acl_entries.append(rule)
-
-            oc_type = self.FAMILY_MAP[address_family]
-
-            oc_acl_set = {
-                "acl-entries": {"acl-entry": oc_acl_entries},
-                "config": {"name": filter_name, "type": oc_type},
-                "name": filter_name,
-                "type": oc_type,
-            }
-            self.acl_sets.append(oc_acl_set)
-
-        logging.info('Total rule count of policy %s is: %d', filter_name, total_rule_count)
+        for term in terms:
+            # Handle mixed for each indvidual term as inet and inet6.
+            # inet/inet6 are treated the same.
+            term_address_families = []
+            if address_family == 'mixed':
+                term_address_families = ['inet', 'inet6']
+            else:
+                term_address_families = [address_family]
+            for term_af in term_address_families:
+                t = self._TERM(term, term_af)
+                for rule in t.ConvertToDict():
+                    self.total_rule_count += 1
+                    rule['sequence-id'] = self.total_rule_count * 5
+                    oc_acl_entries.append(rule)
+        oc_type = self.FAMILY_MAP[address_family]
+        oc_acl_set = {
+            "acl-entries": {"acl-entry": oc_acl_entries},
+            "config": {"name": filter_name, "type": oc_type},
+            "name": filter_name,
+            "type": oc_type,
+        }
+        self.acl_sets.append(oc_acl_set)
 
     def __str__(self) -> str:
         out = '%s\n\n' % (
