@@ -108,6 +108,7 @@ BUILTIN_GENERATORS: list[Tuple] = [
     ('nsxv',                 'aerleon.lib.nsxv',                 'Nsxv'),
     ('nsxt',                 'aerleon.lib.nsxt',                 'Nsxt'),
     ('openconfig',           'aerleon.lib.openconfig',           'OpenConfig'),
+    ('sonic',                'aerleon.lib.sonic',                'SONiC'),
     ('speedway',             'aerleon.lib.speedway',             'Speedway'),
     ('pcap',                 'aerleon.lib.pcap',                 'PcapFilter'),
     ('pcap',                 'aerleon.lib.pcap',                 'PcapFilter'),
@@ -117,6 +118,7 @@ BUILTIN_GENERATORS: list[Tuple] = [
     ('cisconx',              'aerleon.lib.cisconx',              'CiscoNX'),
     ('ciscoxr',              'aerleon.lib.ciscoxr',              'CiscoXR'),
     ('nftables',             'aerleon.lib.nftables',             'Nftables'),
+    ('nokiasrl',             'aerleon.lib.nokiasrl',             'NokiaSRLinux'),
     ('gce',                  'aerleon.lib.gce',                  'GCE'),
     ('gcp_hf',               'aerleon.lib.gcp_hf',               'HierarchicalFirewall'),
     ('paloalto',             'aerleon.lib.paloaltofw',           'PaloAltoFW'),
