@@ -75,6 +75,7 @@ PolicyTerm = TypedDict(
         "expiration": "datetime.date | str",
         "destination-address": WordList,
         "destination-exclude": WordList,
+        "destination-fqdn": WordList,
         "destination-port": WordList,
         "destination-prefix": WordList,
         "filter-term": str,
@@ -96,6 +97,7 @@ PolicyTerm = TypedDict(
         "routing-instance": str,
         "source-address": WordList,
         "source-exclude": WordList,
+        "source-fqdn": WordList,
         "source-port": WordList,
         "source-prefix": WordList,
         "ttl": "int | str",
@@ -450,6 +452,7 @@ BUILTIN_SPEC: "dict[str, TValue | TComposition]" = {
     'expiration':                 TValue.YearMonthDay,
     'destination-address':        TListStrCollapsible,
     'destination-exclude':        TListStrCollapsible,
+    'destination-fqdn':       TListStrCollapsible,
     'destination-port':           TListStrCollapsible,
     'destination-prefix':         TListStrCollapsible,
     'filter-term':                TValue.WordString,
@@ -471,6 +474,7 @@ BUILTIN_SPEC: "dict[str, TValue | TComposition]" = {
     'routing-instance':           TValue.WordString,
     'source-address':             TListStrCollapsible,
     'source-exclude':             TListStrCollapsible,
+    'source-fqdn':            TListStrCollapsible,
     'source-port':                TListStrCollapsible,
     'source-prefix':              TListStrCollapsible,
     'ttl':                        TValue.Integer,
@@ -590,6 +594,8 @@ class _Builtin:
         'vpn':                        (_CallType.SingleValue,  VarType.VPN),
         'source-address':             (_CallType.SingleList,   VarType.SADDRESS),
         'destination-address':        (_CallType.SingleList,   VarType.DADDRESS),
+        'destination-fqdn':       (_CallType.SingleList,   VarType.DESTINATION_FQDN),
+        'source-fqdn':            (_CallType.SingleList,   VarType.SOURCE_FQDN),
         'address':                    (_CallType.SingleList,   VarType.ADDRESS),
         'source-exclude':             (_CallType.SingleList,   VarType.SADDREXCLUDE),
         'destination-exclude':        (_CallType.SingleList,   VarType.DADDREXCLUDE),
@@ -880,6 +886,8 @@ class TermBuiltinRecognizer(BuiltinRecognizer):
             'target-resources',
             'target-service-accounts',
             'timeout',
+            'destination-fqdn',
+            'source-fqdn',
         }
     )
 
@@ -922,5 +930,4 @@ class TermBuiltinRecognizer(BuiltinRecognizer):
             # The policy name field should be given as an empty string if not provided
             # by the user.
             repr = (repr['name'], repr.get('policy', ''))
-
         return repr
