@@ -17,10 +17,13 @@
 """Generic Windows security policy generator; requires subclassing."""
 
 import string
+from typing import Dict, List, Set, Tuple, Union
 
 from absl import logging
 
 from aerleon.lib import aclgenerator, nacaddr
+from aerleon.lib.nacaddr import IPv4, IPv6
+from aerleon.lib.policy import Header, Policy, Term
 
 CMD_PREFIX = 'netsh ipsec static add '
 
@@ -35,7 +38,9 @@ class Term(aclgenerator.Term):
     # filter rules
     _ACTION_TABLE = {}
 
-    def __init__(self, term, filter_name, filter_action, af='inet'):
+    def __init__(
+        self, term: Term, filter_name: str, filter_action: None, af: str = 'inet'
+    ) -> None:
         """Setup a new term.
 
         Args:
@@ -61,7 +66,7 @@ class Term(aclgenerator.Term):
 
         self.term_name = '%s_%s' % (self.filter[:1], self.term.name)
 
-    def __str__(self):
+    def __str__(self) -> str:
         ret_str = []
 
         # Don't render icmpv6 protocol terms under inet, or icmp under inet6
@@ -159,7 +164,7 @@ class Term(aclgenerator.Term):
 
         return '\n'.join(str(v) for v in ret_str if v)
 
-    def _HandleIcmpTypes(self, icmp_types, protocols):
+    def _HandleIcmpTypes(self, icmp_types: List[str], protocols: List[str]) -> Tuple[None, None]:
         """Perform implementation-specific icmp_type and protocol transforms.
 
         Note that icmp_types or protocols are passed as parameters in case they
@@ -175,7 +180,9 @@ class Term(aclgenerator.Term):
         """
         return None, None
 
-    def _HandlePorts(self, src_ports, dst_ports):
+    def _HandlePorts(
+        self, src_ports: List[Tuple[int, int]], dst_ports: List[Tuple[int, int]]
+    ) -> Tuple[None, None]:
         """Perform implementation-specific port transforms.
 
         Note that icmp_types or protocols are passed as parameters in case they
@@ -191,7 +198,7 @@ class Term(aclgenerator.Term):
         """
         return None, None
 
-    def _HandlePreRule(self, ret_str):
+    def _HandlePreRule(self, ret_str: List[str]) -> None:
         """Perform any pre-cartesian product transforms on the ret_str array.
 
         Args:
@@ -201,8 +208,15 @@ class Term(aclgenerator.Term):
         pass
 
     def _CartesianProduct(
-        self, src_addr, dst_addr, protocol, icmp_types, src_ports, dst_ports, ret_str
-    ):
+        self,
+        src_addr: List[Union[IPv4, IPv6]],
+        dst_addr: List[Union[IPv4, IPv6]],
+        protocol: List[str],
+        unused_icmp_types: List[str],
+        src_port: List[str],
+        dst_port: List[str],
+        ret_str: List[str],
+    ) -> None:
         """Perform any the appropriate cartesian product of the input parameters.
 
         Args:
@@ -217,7 +231,7 @@ class Term(aclgenerator.Term):
         """
         pass
 
-    def _HandlePostRule(self, ret_str):
+    def _HandlePostRule(self, ret_str: str) -> None:
         """Perform any port-cartesian product transforms on the ret_str array.
 
         Args:
@@ -239,7 +253,7 @@ class WindowsGenerator(aclgenerator.ACLGenerator):
 
     _GOOD_AFS = ['inet', 'inet6']
 
-    def _BuildTokens(self):
+    def _BuildTokens(self) -> Tuple[Set[str], Dict[str, Set[str]]]:
         """Build supported tokens for platform.
 
         Returns:
@@ -254,7 +268,7 @@ class WindowsGenerator(aclgenerator.ACLGenerator):
         del supported_sub_tokens['option']
         return supported_tokens, supported_sub_tokens
 
-    def _TranslatePolicy(self, pol, exp_info):
+    def _TranslatePolicy(self, pol: Policy, exp_info: int) -> None:
         """Translate a policy from objects into strings."""
         self.windows_policies = []
         default_action = None
@@ -334,7 +348,7 @@ class WindowsGenerator(aclgenerator.ACLGenerator):
                 (header, filter_name, filter_type, default_action, new_terms)
             )
 
-    def __str__(self):
+    def __str__(self) -> str:
         target = []
         pretty_platform = '%s%s' % (self._PLATFORM[0].upper(), self._PLATFORM[1:])
 
@@ -372,8 +386,8 @@ class WindowsGenerator(aclgenerator.ACLGenerator):
         target.append('')
         return '\n'.join(target)
 
-    def _HandlePolicyHeader(self, header, target):
+    def _HandlePolicyHeader(self, header: Header, target: List[str]) -> None:
         pass
 
-    def _HandleTermFooter(self, header, term, target):
+    def _HandleTermFooter(self, header: Header, term: Term, target: List[str]) -> None:
         pass
